D is computed from similarity S according the equation
1/S-1.
The use and evaluation of clustering with this measure can be found e.g. in (Sulc and Rezankova, 2014).eskin(data)n x n, where n is a number of objects in original data. The matrix contains proximities
between all pairs of objects. It can be used in hierarchical cluster analyses (HCA), e.g. in agnes.good1,
good2,
good3,
good4,
iof,
lin,
lin1,
morlini,
of,
sm.#sample data
data(data20)
# Creation of proximity matrix
prox_eskin <- eskin(data20)Run the code above in your browser using DataLab